Struct asoiaf_api::client::Client
source · pub struct Client {}Expand description
The main struct of this library. It is used to make requests to the API. It holds methods to get all the items of a type, or to iterate over them.
Implementations
sourceimpl Client
impl Client
pub fn new() -> Self
pub async fn get_books(&self) -> Result<Vec<Book>, Error>
pub fn get_book_iterator(&self, limit: usize) -> BookIterator
pub fn get_book_filter_iterator( &self, book_filter: BookFilter, limit: usize ) -> BookIterator
pub async fn get_characters(&self) -> Result<Vec<Character>, Error>
pub fn get_character_iterator(&self, limit: usize) -> CharacterIterator
pub fn get_character_filter_iterator( &self, character_filter: CharacterFilter, limit: usize ) -> CharacterIterator
pub async fn get_houses(&self) -> Result<Vec<House>, Error>
pub fn get_house_iterator(&self, limit: usize) -> HouseIterator
pub fn get_house_filter_iterator( &self, house_filter: HouseFilter, limit: usize ) -> HouseIterator